==> amps-c++-client-5.3.3.3-Linux.tar.gz: amps-c++-client-5.3.3.3-Linux/doc/html/search/all_b.js <==
var searchData=
[
  ['map_5ftype',['map_type',['../classAMPS_1_1FIXShredder.html#a2fd96472d6b8cea917632257c67fa8a1',1,'AMPS::FIXShredder']]],
  ['maxdepth',['maxDepth',['../classAMPS_1_1MessageStream.html#a2ff2b7530e4f82c4f664c1da9db03f24',1,'AMPS::MessageStream']]],
  ['memorybookmarkstore',['MemoryBookmarkStore',['../classAMPS_1_1MemoryBookmarkStore.html',1,'AMPS']]],
  ['memorybookmarkstore',['MemoryBookmarkStore',['../classAMPS_1_1MemoryBookmarkStore.html#a5d2b8a438b344ef7c6a349778948f208',1,'AMPS::MemoryBookmarkStore::MemoryBookmarkStore()'],['../classAMPS_1_1MemoryBookmarkStore.html#a6db5462920b519f384efeff31cdf7009',1,'AMPS::MemoryBookmarkStore::MemoryBookmarkStore(const RecoveryPointAdapter &amp;adapter_, RecoveryPointFactory factory_=NULL)']]],
  ['memorybookmarkstore_2ehpp',['MemoryBookmarkStore.hpp',['../MemoryBookmarkStore_8hpp.html',1,'']]],
  ['memorypublishstore',['MemoryPublishStore',['../classAMPS_1_1MemoryPublishStore.html',1,'AMPS']]],
  ['memorypublishstore',['MemoryPublishStore',['../classAMPS_1_1MemoryPublishStore.html#ae3432f0d48a341688f744422498580b8',1,'AMPS::MemoryPublishStore']]],
  ['memorypublishstore_2ehpp',['MemoryPublishStore.hpp',['../MemoryPublishStore_8hpp.html',1,'']]],
  ['memorystorebuffer',['MemoryStoreBuffer',['../classAMPS_1_1MemoryStoreBuffer.html',1,'AMPS']]],
  ['memorystorebuffer_2ehpp',['MemoryStoreBuffer.hpp',['../MemoryStoreBuffer_8hpp.html',1,'']]],
  ['memorysubscriptionmanager',['MemorySubscriptionManager',['../classAMPS_1_1MemorySubscriptionManager.html',1,'AMPS']]],
  ['memorysubscriptionmanager_2ehpp',['MemorySubscriptionManager.hpp',['../MemorySubscriptionManager_8hpp.html',1,'']]],
  ['message',['Message',['../classAMPS_1_1Message.html#a29ab99cb8f1fa8aa96586d0e3adc1acd',1,'AMPS::Message::Message(amps_handle message_, bool owner_=false)'],['../classAMPS_1_1Message.html#ab6c894674391f3fee4b997ad98745ecf',1,'AMPS::Message::Message()']]],
  ['message',['Message',['../classAMPS_1_1Message.html',1,'AMPS']]],
  ['message_2ehpp',['Message.hpp',['../Message_8hpp.html',1,'']]],
  ['messageimpl',['MessageImpl',['../classAMPS_1_1MessageImpl.html#aaf68f220322ede5401d200fe9762b77d',1,'AMPS::MessageImpl::MessageImpl(amps_handle message_, bool owner_=false, bool ignoreAutoAck_=false, size_t bookmarkSeqNo_=0, amps_subscription_handle subscription_=NULL, ClientImpl *clientImpl_=NULL)'],['../classAMPS_1_1MessageImpl.html#af0541dfec289bb72b48eb29ac057adc7',1,'AMPS::MessageImpl::MessageImpl()']]],
  ['messageimpl',['MessageImpl',['../classAMPS_1_1MessageImpl.html',1,'AMPS']]],
  ['messagerouter',['MessageRouter',['../classAMPS_1_1MessageRouter.html',1,'AMPS']]],
  ['messagestream',['MessageStream',['../classAMPS_1_1MessageStream.html',1,'AMPS']]],
  ['mmapbookmarkstore',['MMapBookmarkStore',['../classAMPS_1_1MMapBookmarkStore.html#a9e32d81d841ded7d165277a6c7308a0d',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const char *fileName_, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a369482b700a0b6590dc21cf99b2135ef',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const std::string &amp;fileName_, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a96e539937d6862ba54d341e53d3e21f5',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const RecoveryPointAdapter &amp;adapter_, const char *fileName_, RecoveryPointFactory factory_=NULL, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a3f7f0bf1b28ee93f70142605d4379571',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const RecoveryPointAdapter &amp;adapter_, const std::string &amp;fileName_, RecoveryPointFactory factory_=NULL, bool useLastModifiedTime_=false)']]],
  ['mmapbookmarkstore',['MMapBookmarkStore',['../classAMPS_1_1MMapBookmarkStore.html',1,'AMPS']]],
  ['mmapbookmarkstore_2ehpp',['MMapBookmarkStore.hpp',['../MMapBookmarkStore_8hpp.html',1,'']]],
  ['mmapstorebuffer',['MMapStoreBuffer',['../classAMPS_1_1MMapStoreBuffer.html',1,'AMPS']]],
  ['mmapstorebuffer',['MMapStoreBuffer',['../classAMPS_1_1MMapStoreBuffer.html#aebc73208ee2feb4dd08c1edff1ac5f74',1,'AMPS::MMapStoreBuffer']]],
  ['mmapstorebuffer_2ehpp',['MMapStoreBuffer.hpp',['../MMapStoreBuffer_8hpp.html',1,'']]],
  ['most_5frecent',['MOST_RECENT',['../classAMPS_1_1Client.html#ab99f18871b7d34f23468e76e9a9b97cc',1,'AMPS::Client']]]
];

==> amps-c++-client-5.3.4.5-Linux.tar.gz: amps-c++-client-5.3.4.5-Linux/doc/html/search/all_b.js <==
var searchData=
[
  ['map_5ftype',['map_type',['../classAMPS_1_1FIXShredder.html#a2fd96472d6b8cea917632257c67fa8a1',1,'AMPS::FIXShredder']]],
  ['maxdepth',['maxDepth',['../classAMPS_1_1MessageStream.html#a2ff2b7530e4f82c4f664c1da9db03f24',1,'AMPS::MessageStream']]],
  ['memorybookmarkstore',['MemoryBookmarkStore',['../classAMPS_1_1MemoryBookmarkStore.html',1,'AMPS']]],
  ['memorybookmarkstore',['MemoryBookmarkStore',['../classAMPS_1_1MemoryBookmarkStore.html#a5d2b8a438b344ef7c6a349778948f208',1,'AMPS::MemoryBookmarkStore::MemoryBookmarkStore()'],['../classAMPS_1_1MemoryBookmarkStore.html#a6db5462920b519f384efeff31cdf7009',1,'AMPS::MemoryBookmarkStore::MemoryBookmarkStore(const RecoveryPointAdapter &amp;adapter_, RecoveryPointFactory factory_=NULL)']]],
  ['memorybookmarkstore_2ehpp',['MemoryBookmarkStore.hpp',['../MemoryBookmarkStore_8hpp.html',1,'']]],
  ['memorypublishstore',['MemoryPublishStore',['../classAMPS_1_1MemoryPublishStore.html',1,'AMPS']]],
  ['memorypublishstore',['MemoryPublishStore',['../classAMPS_1_1MemoryPublishStore.html#af37507d1277c964d1c7b5f11a73adeab',1,'AMPS::MemoryPublishStore']]],
  ['memorypublishstore_2ehpp',['MemoryPublishStore.hpp',['../MemoryPublishStore_8hpp.html',1,'']]],
  ['memorystorebuffer',['MemoryStoreBuffer',['../classAMPS_1_1MemoryStoreBuffer.html',1,'AMPS']]],
  ['memorystorebuffer_2ehpp',['MemoryStoreBuffer.hpp',['../MemoryStoreBuffer_8hpp.html',1,'']]],
  ['memorysubscriptionmanager',['MemorySubscriptionManager',['../classAMPS_1_1MemorySubscriptionManager.html',1,'AMPS']]],
  ['memorysubscriptionmanager_2ehpp',['MemorySubscriptionManager.hpp',['../MemorySubscriptionManager_8hpp.html',1,'']]],
  ['message',['Message',['../classAMPS_1_1Message.html#a5208bfe88e69e810f0dc278f9de5b08a',1,'AMPS::Message::Message(CtorFlag)'],['../classAMPS_1_1Message.html#a29ab99cb8f1fa8aa96586d0e3adc1acd',1,'AMPS::Message::Message(amps_handle message_, bool owner_=false)'],['../classAMPS_1_1Message.html#ab6c894674391f3fee4b997ad98745ecf',1,'AMPS::Message::Message()']]],
  ['message',['Message',['../classAMPS_1_1Message.html',1,'AMPS']]],
  ['message_2ehpp',['Message.hpp',['../Message_8hpp.html',1,'']]],
  ['messageimpl',['MessageImpl',['../classAMPS_1_1MessageImpl.html#aaf68f220322ede5401d200fe9762b77d',1,'AMPS::MessageImpl::MessageImpl(amps_handle message_, bool owner_=false, bool ignoreAutoAck_=false, size_t bookmarkSeqNo_=0, amps_subscription_handle subscription_=NULL, ClientImpl *clientImpl_=NULL)'],['../classAMPS_1_1MessageImpl.html#af0541dfec289bb72b48eb29ac057adc7',1,'AMPS::MessageImpl::MessageImpl()']]],
  ['messageimpl',['MessageImpl',['../classAMPS_1_1MessageImpl.html',1,'AMPS']]],
  ['messagerouter',['MessageRouter',['../classAMPS_1_1MessageRouter.html',1,'AMPS']]],
  ['messagestream',['MessageStream',['../classAMPS_1_1MessageStream.html',1,'AMPS']]],
  ['mmapbookmarkstore',['MMapBookmarkStore',['../classAMPS_1_1MMapBookmarkStore.html#a9e32d81d841ded7d165277a6c7308a0d',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const char *fileName_, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a369482b700a0b6590dc21cf99b2135ef',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const std::string &amp;fileName_, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a96e539937d6862ba54d341e53d3e21f5',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const RecoveryPointAdapter &amp;adapter_, const char *fileName_, RecoveryPointFactory factory_=NULL, bool useLastModifiedTime_=false)'],['../classAMPS_1_1MMapBookmarkStore.html#a3f7f0bf1b28ee93f70142605d4379571',1,'AMPS::MMapBookmarkStore::MMapBookmarkStore(const RecoveryPointAdapter &amp;adapter_, const std::string &amp;fileName_, RecoveryPointFactory factory_=NULL, bool useLastModifiedTime_=false)']]],
  ['mmapbookmarkstore',['MMapBookmarkStore',['../classAMPS_1_1MMapBookmarkStore.html',1,'AMPS']]],
  ['mmapbookmarkstore_2ehpp',['MMapBookmarkStore.hpp',['../MMapBookmarkStore_8hpp.html',1,'']]],
  ['mmapstorebuffer',['MMapStoreBuffer',['../classAMPS_1_1MMapStoreBuffer.html',1,'AMPS']]],
  ['mmapstorebuffer',['MMapStoreBuffer',['../classAMPS_1_1MMapStoreBuffer.html#aebc73208ee2feb4dd08c1edff1ac5f74',1,'AMPS::MMapStoreBuffer']]],
  ['mmapstorebuffer_2ehpp',['MMapStoreBuffer.hpp',['../MMapStoreBuffer_8hpp.html',1,'']]],
  ['most_5frecent',['MOST_RECENT',['../classAMPS_1_1Client.html#ab99f18871b7d34f23468e76e9a9b97cc',1,'AMPS::Client']]]
];
